@@ -116,13 +116,13 @@ class Core():
         if project is None and (project_namespace is None or project_name is None):
             raise Exception("Need a project or its namespace and name")
         if project is None:
-            self.project_data_dit = Path(self.data_root_dir,project_namespace,project_name)
-            self.project_data_dit.mkdir(parents=True, exist_ok=True)
+            self.project_data_dir = Path(self.data_root_dir,project_namespace,project_name)
+            self.project_data_dir.mkdir(parents=True, exist_ok=True)
         else:
             self.project_namespace = project.attributes["namespace"]["path"]
             self.project_name = project.attributes["path"]
-            self.project_data_dit = Path(self.data_root_dir,project.attributes["path_with_namespace"])
-            self.project_data_dit.mkdir(parents=True, exist_ok=True)
+            self.project_data_dir = Path(self.data_root_dir,project.attributes["path_with_namespace"])
+            self.project_data_dir.mkdir(parents=True, exist_ok=True)
 
     def connect(self, server_url:str, private_token:str=None, oauth_token:str=None, job_token:str=None) -> None:
         """
@@ -169,7 +169,7 @@ class Core():
         if filename == Core.Features.PROJECTS:
             pd_file = Path(self.data_root_dir, f"{filename}.p")
         else:
-            pd_file = Path(self.project_data_dit, f"{filename}.p")
+            pd_file = Path(self.project_data_dir, f"{filename}.p")
         with open(pd_file, "wb") as f:
             pickle.dump(data, f)
     
@@ -195,12 +195,40 @@ class Core():
         if filename == Core.Features.PROJECTS:
             pd_file = Path(self.data_root_dir, f"{filename}.p")
         else:
-            pd_file = Path(self.project_data_dit, f"{filename}.p")
+            pd_file = Path(self.project_data_dir, f"{filename}.p")
         if pd_file.is_file():
             return pd.read_pickle(pd_file)
         else:
             return None
               
+    def get_pandas_data_frame_path(self, filename:str) -> Union[str,None]:
+        """    
+        Get a pandas DataFrame path from the project directory.
+        The project metadata will be excessed from the top level directory.
+
+        Parameters
+        ----------
+        filename : str
+            Name of the feature to get the file path.
+    
+    
+        Returns
+        -------
+        str
+            Return a str path of the feature.
+        None
+            Return None because the file does not exists.
+
+        """
+        if filename == Core.Features.PROJECTS:
+            pd_file = Path(self.data_root_dir, f"{filename}.p")
+        else:
+            pd_file = Path(self.project_data_dir, f"{filename}.p")
+        if pd_file.is_file():
+            return str(pd_file)
+        else:
+            return None
+
     def convert_to_excel(self, excel_filename, features:list = None) -> None:
         """    
         Converts features to an excel file. If no features are passed, then all features will be converted.
@@ -213,7 +241,7 @@ class Core():
             Features to convert. If no features are passed, then all features will be converted.
             
         """
-        writer = pd.ExcelWriter(Path(self.project_data_dit, f'{excel_filename}.xlsx'), engine='xlsxwriter')
+        writer = pd.ExcelWriter(Path(self.project_data_dir, f'{excel_filename}.xlsx'), engine='xlsxwriter')
         if features is None:
             features = Core.Features.to_list()
         for feature in features:
